==> kwave_0.8.8-1.orig.tar.bz2: kwave-0.8.8/plugins/codec_wav/WavFormatMap.h <==
/***************************************************************************
         WavFormatMap.h  -  list of known wav file formats
			     -------------------
    begin                : Apr 28 2002
    copyright            : (C) 2002 by Thomas Eschenbacher
    email                : Thomas Eschenbacher <thomas.eschenbacher@gmx.de>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _WAV_FORMAT_MAP_H_
#define _WAV_FORMAT_MAP_H_

#include "config.h"

#include <QMap>
#include <QString>

#include "WavFileFormat.h"

/**
 * list of known wav file formats
 */
class WavFormatMap: public QMap<wav_format_id, QString>
{
public:
    /** Constructor, fills the map with all known types */
    WavFormatMap();

    /** Destructor */
    virtual ~WavFormatMap() {};

    /** Returns the name of an id, or "unknown" if not found. */
    const QString &findName(unsigned int id);

};

#endif /* _WAV_FORMAT_MAP_H_ */

==> kwave_0.8.11-1.orig.tar.bz2: kwave-0.8.11/plugins/codec_wav/WavFormatMap.h <==
/***************************************************************************
         WavFormatMap.h  -  list of known wav file formats
			     -------------------
    begin                : Apr 28 2002
    copyright            : (C) 2002 by Thomas Eschenbacher
    email                : Thomas Eschenbacher <thomas.eschenbacher@gmx.de>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _WAV_FORMAT_MAP_H_
#define _WAV_FORMAT_MAP_H_

#include "config.h"

#include <QtCore/QMap>
#include <QtCore/QString>

#include "WavFileFormat.h"

namespace Kwave
{
    /**
     * list of known wav file formats
     */
    class WavFormatMap: public QMap<Kwave::wav_format_id, QString>
    {
    public:
	/** Constructor, fills the map with all known types */
	WavFormatMap();

	/** Destructor */
	virtual ~WavFormatMap() {};

	/** Returns the name of an id, or "unknown" if not found. */
	const QString &findName(unsigned int id);

    };
}

#endif /* _WAV_FORMAT_MAP_H_ */

//***************************************************************************
//***************************************************************************
